/******************************************************************************
*******************************************************************************
**
**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
**  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
**
**  This copyrighted material is made available to anyone wishing to use,
**  modify, copy, or redistribute it subject to the terms and conditions
**  of the GNU General Public License v.2.
**
*******************************************************************************
******************************************************************************/

#ifdef __linux__
#ifdef __KERNEL__
#include "osi.h"
#include <linux/string.h>
#else
#include <string.h>
#include "linux_endian.h"
#endif
#endif

#ifdef __FreeBSD__
#ifdef _KERNEL
#include "osi.h"
#else
#include "linux_endian.h"
#endif
#endif


#include "cidev.h"


#define CPIN_8(x, y, z) {memcpy((x), (y), (z));}
#define CPOUT_8(x, y, z) {memcpy((y), (x), (z));}
#define CPIN_16(x, y) {(x) = be16_to_cpu((y));}
#define CPOUT_16(x, y) {(y) = cpu_to_be16((x));}
#define CPIN_32(x, y) {(x) = be32_to_cpu((y));}
#define CPOUT_32(x, y) {(y) = cpu_to_be32((x));}
#define CPIN_64(x, y) {(x) = be64_to_cpu((y));}
#define CPOUT_64(x, y) {(y) = cpu_to_be64((x));}



void cidev_header_in(cidev_header_t *ch, char *buf)
{
  cidev_header_t *bufch = (cidev_header_t *)buf;

  CPIN_32(ch->magic, bufch->magic);
  CPIN_32(ch->inuse, bufch->inuse);
  CPIN_32(ch->version, bufch->version);

  CPIN_8(ch->name, bufch->name, 256);
}


void cidev_header_out(cidev_header_t *ch, char *buf)
{
  cidev_header_t *bufch = (cidev_header_t *)buf;

  CPOUT_32(ch->magic, bufch->magic);
  CPOUT_32(ch->inuse, bufch->inuse);
  CPOUT_32(ch->version, bufch->version);

  CPOUT_8(ch->name, bufch->name, 256);
}


void cidev_marker_in(cidev_marker_t *cm, char *buf)
{
  cidev_marker_t *bufcm = (cidev_marker_t *)buf;

  CPIN_32(cm->magic, bufcm->magic);
  CPIN_32(cm->inuse, bufcm->inuse);
}


void cidev_marker_out(cidev_marker_t *cm, char *buf)
{
  cidev_marker_t *bufcm = (cidev_marker_t *)buf;

  CPOUT_32(cm->magic, bufcm->magic);
  CPOUT_32(cm->inuse, bufcm->inuse);
}

