/******************************************************************************
*******************************************************************************
**
**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
**  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
**
**  This copyrighted material is made available to anyone wishing to use,
**  modify, copy, or redistribute it subject to the terms and conditions
**  of the GNU General Public License v.2.
**
*******************************************************************************
******************************************************************************/

#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <errno.h>
#include <time.h>
#include <sys/ioctl.h>
#include <sys/stat.h>
#include <unistd.h>
#include <ctype.h>

#include "global.h"
#include <linux/gfs_ioctl.h>

#include "gfs_tool.h"



#if GFS_COUNTERS_VERSION != (((0) << 16) | (240))
#error update GFS/src/tool/gfs_tool/counters.c
#endif





/**
 * get_counters - print out the current countersable parameters for a filesystem
 * @argc:
 * @argv:
 *
 */

void get_counters(int argc, char **argv)
{
  struct gfs_counters gc;
  int fd;
  int continuous = FALSE;
  int error;


  if (argc == 4)
  {
    if (!strcmp(argv[3], "-c"))
      continuous = TRUE;
    else
      die("Usage: gfs_tool counters <GFS_directory> [-c]\n");
  }
  else if (argc != 3)
    die("Usage: gfs_tool counters <GFS_directory> [-c]\n");


  fd = open(argv[2], O_RDONLY);
  if (fd < 0)
    die("can't open file %s: %s\n", argv[2], strerror(errno));

  check_for_gfs(fd, argv[2]);


  for (;;)
  {
    error = ioctl(fd, GFS_GET_COUNTERS, &gc);
    if (error)
      die("can't get counters: %s\n", strerror(errno));

    if (gc.gc_counters_version != GFS_COUNTERS_VERSION)
      die("gfs_tool and gfs versions are mismatched\n");

    printf("\nAbsolute:\n");
    printf("locks = %u\n", gc.gc_locks);
    printf("locks held = %u\n", gc.gc_locks_held);
    printf("incore inodes = %u\n", gc.gc_inodes);
    printf("unlinked inodes = %u\n", gc.gc_unlinked_inodes);
    printf("quota IDs = %u\n", gc.gc_quota_ids);
    printf("incore log buffers = %u\n", gc.gc_iclog_buffers);
    printf("log space used = %.2f%%\n",
	   100.0 * (gc.gc_log_seg_total - gc.gc_log_seg_free) / gc.gc_log_seg_total);
    printf("mh cache entries = %u\n", gc.gc_mh_cache_count);
    printf("glock dependencies = %u\n", gc.gc_dependencies);
    printf("glocks on reclaim list = %u\n", gc.gc_reclaim_count);
    printf("log wraps = %u\n", gc.gc_log_wraps);
    printf("\nSince Last:\n");
    printf("fh2dentry misses = %u\n", gc.gc_fh2dentry_misses);
    printf("glocks reclaimed = %u\n", gc.gc_reclaimed);
    printf("glock nq calls = %u\n", gc.gc_glock_nq_calls);
    printf("glock dq calls = %u\n", gc.gc_glock_dq_calls);
    printf("glock prefetch calls = %u\n", gc.gc_glock_prefetch_calls);
    printf("lm_lock calls = %u\n", gc.gc_lm_lock_calls);
    printf("lm_unlock calls = %u\n", gc.gc_lm_unlock_calls);
    printf("lm callbacks = %u\n", gc.gc_lm_callbacks);

    if (!continuous)
      break;

    fflush(stdout);

    sleep(1);
  }


  close(fd);
}


