/******************************************************************************
*******************************************************************************
**
**  Copyright (C) Sistina Software, Inc.  1997-2003  All rights reserved.
**  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
**
**  This copyrighted material is made available to anyone wishing to use,
**  modify, copy, or redistribute it subject to the terms and conditions
**  of the GNU General Public License v.2.
**
*******************************************************************************
******************************************************************************/

#ifndef __LVB_DOT_H__
#define __LVB_DOT_H__

#define GFS_MIN_LVB_SIZE (32)

struct gfs_rgrp_lvb {
	uint32_t rb_magic;

	uint32_t rb_free;	/* Caching RG usage data */
	uint32_t rb_useddi;
	uint32_t rb_freedi;
	uint32_t rb_usedmeta;
	uint32_t rb_freemeta;
	uint16_t rb_owner;	/* JID of owner + 1 */
};

#define GFS_PLOCK_PHEAD_MAGIC (0xF3123B0A)

struct gfs_plock_phead {
	uint32_t ph_magic;
	uint32_t ph_gid;	/* inode number */
};

#define GFS_PLOCK_JHEAD_MAGIC (0xF31E8A20)

struct gfs_plock_jhead {
	uint32_t pj_magic;
	uint16_t pj_lid;
	uint16_t pj_jid;
};

#define GFS_PLOCK_ELEM_MAGIC (0xF312C32B)

struct gfs_plock_elem {
	uint32_t pe_magic;
	uint32_t pe_pid;
	uint64_t pe_start;
	uint64_t pe_end;
	uint16_t pe_excl;
	uint16_t pe_next_lid;
	uint16_t pe_mylid;	/* zeroed to invalidate */
};

struct gfs_quota_lvb {
	uint32_t qb_magic;
	uint32_t qb_pad;
	uint64_t qb_limit;
	uint64_t qb_warn;
	int64_t qb_value;
};

/*  Translation functions  */

void gfs_rgrp_lvb_in(struct gfs_rgrp_lvb *rb, char *lvb);
void gfs_rgrp_lvb_out(struct gfs_rgrp_lvb *rb, char *lvb);
void gfs_plock_phead_in(struct gfs_plock_phead *php, char *lvb);
void gfs_plock_phead_out(struct gfs_plock_phead *php, char *lvb);
void gfs_plock_jhead_in(struct gfs_plock_jhead *jhp, char *lvb);
void gfs_plock_jhead_out(struct gfs_plock_jhead *jhp, char *lvb);
void gfs_plock_elem_in(struct gfs_plock_elem *pep, char *lvb);
void gfs_plock_elem_out(struct gfs_plock_elem *pep, char *lvb);
void gfs_quota_lvb_in(struct gfs_quota_lvb *qb, char *lvb);
void gfs_quota_lvb_out(struct gfs_quota_lvb *qb, char *lvb);

/*  Printing functions  */

void gfs_rgrp_lvb_print(struct gfs_rgrp_lvb *rb, int console);
void gfs_plock_phead_print(struct gfs_plock_phead *ph, int console);
void gfs_plock_jhead_print(struct gfs_plock_jhead *jh, int console);
void gfs_plock_elem_print(struct gfs_plock_elem *el, int console);
void gfs_quota_lvb_print(struct gfs_quota_lvb *qb, int console);

#endif				/*  __LVB_DOT_H__  */
